@@ -41,15 +41,6 @@ Preferences::Preferences( Gtk::Window* parent, const std::string& url )
         if( DBTREE::article_write_time( get_url() ) ) m_label_write.set_text( DBTREE::article_write_date( get_url() ) );
     }
 
-    // 透明あぼーん
-    m_check_transpabone.set_active( DBTREE::get_abone_transparent( get_url() ) );
-
-    // 連鎖あぼーん
-    m_check_chainabone.set_active( DBTREE::get_abone_chain( get_url() ) );
-
-    if( CONFIG::get_abone_transparent() ) m_check_transpabone.set_sensitive( false );
-    if( CONFIG::get_abone_chain() ) m_check_chainabone.set_sensitive( false );
-
     m_vbox_info.set_border_width( 16 );
     m_vbox_info.set_spacing( 8 );
     m_vbox_info.pack_start( m_label_name, Gtk::PACK_SHRINK );
@@ -62,13 +53,28 @@ Preferences::Preferences( Gtk::Window* parent, const std::string& url )
     m_vbox_info.pack_start( m_label_modified, Gtk::PACK_SHRINK );
     m_vbox_info.pack_start( m_label_write, Gtk::PACK_SHRINK );
 
+    // あぼーん設定
+
+    m_vbox_abone.set_border_width( 16 );
+    m_vbox_abone.set_spacing( 8 );
+
+    // 透明あぼーん
+    m_check_transpabone.set_active( DBTREE::get_abone_transparent( get_url() ) );
+
+    // 連鎖あぼーん
+    m_check_chainabone.set_active( DBTREE::get_abone_chain( get_url() ) );
+
+    if( CONFIG::get_abone_transparent() ) m_check_transpabone.set_sensitive( false );
+    if( CONFIG::get_abone_chain() ) m_check_chainabone.set_sensitive( false );
+
+    m_vbox_abone.pack_start( m_check_transpabone, Gtk::PACK_SHRINK );
+    m_vbox_abone.pack_start( m_check_chainabone, Gtk::PACK_SHRINK );
+
     if( CONFIG::get_abone_transparent() || CONFIG::get_abone_chain() ){
         m_label_abone.set_text( "チェック出来ない場合は設定メニューから「デフォルトで透明/連鎖あぼ〜ん」を解除して下さい" );
         m_label_abone.set_alignment( Gtk::ALIGN_LEFT, Gtk::ALIGN_CENTER );
-        m_vbox_info.pack_end( m_label_abone, Gtk::PACK_SHRINK );
+        m_vbox_abone.pack_start( m_label_abone, Gtk::PACK_SHRINK );
     }
-    m_vbox_info.pack_end( m_check_chainabone, Gtk::PACK_SHRINK );
-    m_vbox_info.pack_end( m_check_transpabone, Gtk::PACK_SHRINK );
 
     if( DBTREE::article_is_cached( get_url() ) ){ 
 
@@ -80,12 +86,35 @@ Preferences::Preferences( Gtk::Window* parent, const std::string& url )
         for( it = list_id.begin(); it != list_id.end(); ++it ) if( ! ( *it ).empty() ) str_id += ( *it ) + "\n";
         m_edit_id.set_text( str_id );
 
-        // res
+        // あぼーんレス番号
+        // 連番は 12-34 の様なフォーマットに変換
         std::vector< char > vec_res = DBTREE::get_abone_vec_res( get_url() );
         std::vector< char >::iterator it_res = vec_res.begin();
-        for( int res = 0 ; it_res != vec_res.end(); ++it_res, ++res ){
-            if( ( *it_res ) ) str_res += MISC::itostr( res ) + "\n";
+        int res = 0;
+        int pre_res = 0;
+        int count = 0;
+        for( ; it_res != vec_res.end(); ++res ){
+
+            if( ( *it_res ) ){
+                if( ! pre_res ) pre_res = res;
+                ++count;
+            }
+
+            ++it_res;
+
+            if( !( *it_res ) || it_res == vec_res.end() ){
+
+                if( pre_res ){
+                    str_res += MISC::itostr( pre_res );
+                    if( count > 1 ) str_res += "-" + MISC::itostr( pre_res + count -1 );
+                    str_res += "\n";
+                    pre_res = 0;
+                    count = 0;
+                }
+            }
         }
+
+
         m_edit_res.set_text( str_res );
 
         // name
@@ -111,12 +140,20 @@ Preferences::Preferences( Gtk::Window* parent, const std::string& url )
         m_edit_regex.set_editable( false );
     }
 
+    m_label_abone_id.set_text( "ここでIDを削除してもレスが表示されない場合は板全体に対してIDがあぼーん指定されている可能性があります。\n板のプロパティのあぼーん設定も確認してください。" );
+    m_vbox_abone.set_spacing( 8 );
+    m_vbox_abone_id.pack_start( m_label_abone_id, Gtk::PACK_SHRINK );
+    m_vbox_abone_id.pack_start( m_edit_id );
+
+    m_notebook_abone.append_page( m_vbox_abone, "一般" );
+    m_notebook_abone.append_page( m_vbox_abone_id, "NG ID" );
+    m_notebook_abone.append_page( m_edit_res, "NG レス番号" );
+    m_notebook_abone.append_page( m_edit_name, "NG 名前" );
+    m_notebook_abone.append_page( m_edit_word, "NG ワード" );
+    m_notebook_abone.append_page( m_edit_regex, "NG 正規表現" );
+
     m_notebook.append_page( m_vbox_info, "一般" );
-    m_notebook.append_page( m_edit_id, "NG ID" );
-    m_notebook.append_page( m_edit_res, "NG レス番号" );
-    m_notebook.append_page( m_edit_name, "NG 名前" );
-    m_notebook.append_page( m_edit_word, "NG ワード" );
-    m_notebook.append_page( m_edit_regex, "NG 正規表現" );
+    m_notebook.append_page( m_notebook_abone, "あぼーん設定" );
 
     get_vbox()->pack_start( m_notebook );
     set_title( "「" + DBTREE::article_subject( get_url() ) + "」のプロパティ" );
@@ -139,13 +176,21 @@ void Preferences::slot_ok_clicked()
     std::list< std::string > list_word = MISC::get_lines( m_edit_word.get_text() );
     std::list< std::string > list_regex = MISC::get_lines( m_edit_regex.get_text() );
 
+    // あぼーんレス番号
     std::vector< char > vec_abone_res;
-    vec_abone_res.resize( DBTREE::article_number_load( get_url() ) );
+    vec_abone_res.resize( DBTREE::article_number_load( get_url() ) + 1 );
     std::list< std::string > list_res = MISC::get_lines( m_edit_res.get_text() );
     std::list< std::string >::iterator it = list_res.begin();
     for( ; it != list_res.end(); ++it ){
-        int number = atoi( (*it).c_str() );
-        if( number ) vec_abone_res[ number ] = true;
+
+        std::string num_str = ( *it );
+        int number = atoi( num_str.c_str() );
+        if( number >= 1 ){
+            int number_end = number;
+            size_t pos = num_str.find( "-" );
+            if( pos != std::string::npos ) number_end = MAX( number, atoi( num_str.substr( pos + 1 ).c_str() ) );
+            for( int i = number; i <= number_end; ++i ) vec_abone_res[ i ] = true;
+        }
     }
 
     DBTREE::reset_abone( get_url(), list_id, list_name, list_word, list_regex, vec_abone_res
