@@ -4,13 +4,13 @@
 #include "jddebug.h"
 
 #include "favoriteview.h"
-#include "bbslistadmin.h"
-#include "selectdialog.h"
 
 #include "cache.h"
-#include "sharedbuffer.h"
 #include "global.h"
 
+// ルート要素名( bookmark.xml )
+#define ROOT_NODE_NAME "favorite"
+
 using namespace BBSLIST;
 
 
@@ -20,8 +20,10 @@ FavoriteListView::FavoriteListView( const std::string& url,
 {
     // D&D可
     get_treeview().set_reorderable_view( true );
-}
 
+    get_toolbar().set_combo( COMBO_FAVORITE );
+}
+ 
 
 FavoriteListView::~FavoriteListView()
 {
@@ -29,54 +31,42 @@ FavoriteListView::~FavoriteListView()
     std::cout << "FavoriteList::~FavoriteList : " << get_url() << std::endl;
 #endif 
 
-    save_xml( CACHE::path_xml_favorite() );
+    save_xml( false );
 }
 
 
-void FavoriteListView::shutdown()
+// xml保存
+void FavoriteListView::save_xml( bool backup )
 {
-#ifdef _DEBUG    
-    std::cout << "FavoriteList::shutdown\n";
-#endif
-    save_xml( CACHE::path_xml_favorite_bkup() );
+    std::string file = CACHE::path_xml_favorite();
+    if( backup ) file = CACHE::path_xml_favorite_bkup();
+
+    save_xml_impl( file, ROOT_NODE_NAME, "" );
 }
 
 
-//
-// コマンド
-//
-bool FavoriteListView::set_command( const std::string& command, const std::string& arg )
-{
-    if( command == "append_favorite" ) append_favorite();
-    if( command == "save_favorite" ) save_xml( CACHE::path_xml_favorite() );
-
-    return true;
-}
-
-
-
 //
 // 表示
 //
 void FavoriteListView::show_view()
 {
     std::string xml;
-    CACHE::load_rawdata( CACHE::path_xml_favorite() , xml );
-    xml2tree( xml );
+
+    // ファイルが存在しなければ入力を旧ファイル名にする
+    std::string file_in = CACHE::path_xml_favorite();
+    if( CACHE::file_exists( file_in ) != CACHE::EXIST_FILE )
+    {
+    	file_in = CACHE::path_xml_favorite_old();
+    }
+
+    CACHE::load_rawdata( file_in, xml );
+
+    xml2tree( std::string( ROOT_NODE_NAME ), xml );
+
     update_urls();
 }
 
 
-//
-// 内容更新
-//
-void FavoriteListView::update_item( const std::string& )
-{
-    update_urls();
-}
-
-
-
 //
 // ポップアップメニュー取得
 //
@@ -101,27 +91,3 @@ Gtk::Menu* FavoriteListView::get_popupmenu( const std::string& url )
 
     return popupmenu;
 }
-
-
-//
-// お気に入りにアイテム追加
-//
-// あらかじめ共有バッファにデータを入れておくこと
-//
-void  FavoriteListView::append_favorite()
-{
-    if( CORE::SBUF_size() == 0 ) return;
-    
-    SelectListDialog diag( get_url(), get_treestore() );
-    if( diag.run() != Gtk::RESPONSE_OK ) return;
-    append_from_buffer( diag.get_path(), true, true );
-}
-
-
-//
-// お気に入り保存
-//
-void FavoriteListView::save_xml( const std::string& file )
-{
-    if( get_ready_tree() ) CACHE::save_rawdata( file , tree2xml() );
-}
