@@ -87,25 +87,35 @@ std::string CACHE::path_root()
 // 板リスト
 std::string CACHE::path_xml_listmain()
 {
-    return CACHE::path_root() +  "list_main.xml";
+    return CACHE::path_root() +  "boards.xml";
 }
 
 std::string CACHE::path_xml_listmain_bkup()
 {
     return CACHE::path_xml_listmain() + ".bkup";
 }
+// 1.9.5-beta070611以前
+std::string CACHE::path_xml_listmain_old()
+{
+    return CACHE::path_root() +  "list_main.xml";
+}
 
 
 // お気に入り
 std::string CACHE::path_xml_favorite()
 {
-    return CACHE::path_root() +  "favorite.xml";
+    return CACHE::path_root() +  "bookmark.xml";
 }
 
 std::string CACHE::path_xml_favorite_bkup()
 {
     return CACHE::path_xml_favorite() + ".bkup";
 }
+// 1.9.5-beta070611以前
+std::string CACHE::path_xml_favorite_old()
+{
+    return CACHE::path_root() +  "favorite.xml";
+}
 
 
 // 外部板設定ファイル( navi2ch 互換 )
@@ -125,6 +135,11 @@ std::string CACHE::path_usrcmd()
 
 // 履歴
 std::string CACHE::path_xml_history()
+{
+    return CACHE::path_root() +  "hist.xml";
+}
+// 1.9.5-beta070611以前
+std::string CACHE::path_xml_history_old()
 {
     return CACHE::path_root() +  "history.xml";
 }
@@ -132,11 +147,28 @@ std::string CACHE::path_xml_history()
 
 // 板履歴
 std::string CACHE::path_xml_history_board()
+{
+    return CACHE::path_root() +  "hist_board.xml";
+}
+// 1.9.5-beta070611以前
+std::string CACHE::path_xml_history_board_old()
 {
     return CACHE::path_root() +  "history_board.xml";
 }
 
 
+// 最近閉じたスレの履歴
+std::string CACHE::path_xml_history_close()
+{
+    return CACHE::path_root() +  "hist_close.xml";
+}
+// 1.9.5-beta070611以前
+std::string CACHE::path_xml_history_close_old()
+{
+    return CACHE::path_root() +  "history_close.xml";
+}
+
+
 // 板移転情報
 std::string CACHE::path_movetable()
 {
@@ -258,6 +290,33 @@ std::string CACHE::path_img_info_root()
 }
 
 
+//
+// 保護画像キャッシュのルートパス
+//
+std::string CACHE::path_img_protect_root()
+{
+    return CACHE::path_root() + "image_protect/";
+}
+
+
+//
+// 保護画像キャッシュのinfoファイルのルートパス
+//
+std::string CACHE::path_img_protect_info_root()
+{
+    return path_img_protect_root() + "info/";
+}
+
+
+//
+// 画像あぼーんinfoファイルのルートパス
+//
+std::string CACHE::path_img_abone_root()
+{
+    return path_root() + "image_abone/";
+}
+
+
 //
 // 書き込みログ
 //
@@ -267,6 +326,16 @@ std::string CACHE::path_postlog()
 }
 
 
+//
+// 検索や名前などの補完情報
+//
+std::string CACHE::path_completion( int mode )
+{
+    return CACHE::path_root() +  "comp" + MISC::itostr( mode ) + ".info";
+}
+
+
+
 //
 // 画像キャッシュファイルの名前
 //
@@ -282,6 +351,15 @@ std::string CACHE::filename_img( const std::string& url )
 }
 
 
+//
+// 画像キャッシュ情報ファイルの名前
+//
+std::string CACHE::filename_img_info( const std::string& url )
+{
+    return filename_img( url ) + ".info";
+}
+
+
 //
 // 画像キャッシュファイルのパス
 //
@@ -296,7 +374,34 @@ std::string CACHE::path_img( const std::string& url )
 //
 std::string CACHE::path_img_info( const std::string& url )
 {
-    return CACHE::path_img_info_root() + filename_img( url ) + ".info";
+    return CACHE::path_img_info_root() + filename_img_info( url );
+}
+
+
+//
+// 保護画像キャッシュファイルのパス
+//
+std::string CACHE::path_img_protect( const std::string& url )
+{
+    return CACHE::path_img_protect_root() + filename_img( url );
+}
+
+
+//
+// 保護画像infoファイルのパス
+//
+std::string CACHE::path_img_protect_info( const std::string& url )
+{
+    return CACHE::path_img_protect_info_root() + filename_img_info( url );
+}
+
+
+//
+// 画像あぼーんinfoファイルのパス
+//
+std::string CACHE::path_img_abone( const std::string& url )
+{
+    return CACHE::path_img_abone_root() + filename_img_info( url );
 }
 
 
@@ -318,6 +423,33 @@ std::string CACHE::path_aadir()
 }
 
 
+//
+// AAの使用履歴ファイル
+//
+std::string CACHE::path_aahistory()
+{
+    return CACHE::path_root() +  "hist_aa.xml";
+}
+
+
+//
+// css
+//
+std::string CACHE::path_css()
+{
+    return CACHE::path_root() +  "jd.css";
+}
+
+
+//
+// res.html
+//
+std::string CACHE::path_reshtml()
+{
+    return CACHE::path_root() +  "Res.html";
+}
+
+
 //
 // キャッシュのルートディレクトリをmkdir
 //
@@ -339,7 +471,7 @@ bool CACHE::mkdir_root()
 //
 // 画像キャッシュのルートディレクトリをmkdir
 //
-// 例えば  "/home/hoge/.jd/image/" と "/home/hoge/.jd/image/info/" を作成
+// 例えば  "/home/hoge/.jd/image/" と "/home/hoge/.jd/image/info/" などを作成
 //
 bool CACHE::mkdir_imgroot()
 {
@@ -357,9 +489,40 @@ bool CACHE::mkdir_imgroot()
         return false;
     }
     
+    // abone ディレクトリ
+    std::string path_abone_root = CACHE::path_img_abone_root();
+    if( ! CACHE::jdmkdir( path_abone_root ) ){
+        MISC::ERRMSG( "can't create " + path_abone_root );
+        return false;
+    }
+
     return true;
 }
 
+
+//
+// 保護画像キャッシュのルートディレクトリをmkdir
+//
+bool CACHE::mkdir_imgroot_favorite()
+{
+    // root
+    std::string path_img_root = CACHE::path_img_protect_root();
+    if( ! CACHE::jdmkdir( path_img_root ) ){
+        MISC::ERRMSG( "can't create " + path_img_root );
+        return false;
+    }
+
+    // info ディレクトリ
+    std::string path_info_root = CACHE::path_img_protect_info_root();
+    if( ! CACHE::jdmkdir( path_info_root ) ){
+        MISC::ERRMSG( "can't create " + path_info_root );
+        return false;
+    }
+    
+    return true;
+}
+
+
 //
 // キャッシュのひとつ上のディレクトリをmkdir
 //
@@ -439,26 +602,46 @@ size_t CACHE::load_rawdata( const std::string& path, char* data, size_t n )
 }
 
 
-bool CACHE::save_rawdata( const std::string& path, const std::string& str, bool append )
+size_t CACHE::save_rawdata( const std::string& path, const std::string& str, bool append )
 {
     return save_rawdata( path, str.c_str(), str.length(), append );
 }
 
 
 
-bool CACHE::save_rawdata( const std::string& path, const char* data, size_t n, bool append )
+size_t CACHE::save_rawdata( const std::string& path, const char* data, size_t n, bool append )
 {
+    size_t count = 0;
+    size_t byte = 0;
     std::ofstream fout;
     if( append ) fout.open( path.c_str(), std::ios::app );
     else fout.open( path.c_str() );
     if( !fout.is_open() ){
         MISC::ERRMSG( "can't open " + path );
-        return false;
+        return 0;
     }
+
+    if( append ) count = fout.tellp();
+
+#ifdef _DEBUG
+    std::cout << "CACHE::save_rawdata current = " << count << std::endl;
+#endif
+
     fout.write( data, n );
+    byte = fout.tellp();
+    byte -= count;
     fout.close();
 
-    return true;
+#ifdef _DEBUG
+    std::cout << "n = " << n << " byte = " << byte << std::endl;
+#endif
+
+    if( n != byte ){
+        MISC::ERRMSG( "failed to save " + path );
+        return 0;
+    }
+
+    return byte;
 }
 
 
@@ -560,7 +743,7 @@ bool CACHE::jdcopy( const std::string& file_from, const std::string& file_to )
 #ifdef _DEBUG
     std::cout << "CACHE::jdcopy : from = " << file_from << std::endl;
     std::cout << "to = " << file_to << std::endl;
-    std::cout << "size = " << buf_stat.st_size << std::endl;
+    std::cout << "read size = " << buf_stat.st_size << std::endl;
 #endif    
 
     // 32Mより大きい画像はエラー出す
@@ -568,15 +751,100 @@ bool CACHE::jdcopy( const std::string& file_from, const std::string& file_to )
             MISC::ERRMSG( "CACHE::jdcopy: size is too big : " + file_from );
             return false;
     }
-    
+
+    bool ret = false;
     char* data = (char*)malloc( sizeof( char ) *  buf_stat.st_size );
 
-    load_rawdata( file_from, data, buf_stat.st_size );
-    save_rawdata( file_to, data, buf_stat.st_size );
+    size_t readsize = load_rawdata( file_from, data, buf_stat.st_size );
+    if( readsize ){
+        size_t savesize = save_rawdata( file_to, data, buf_stat.st_size );
+        if( readsize == savesize ) ret = true;
+
+#ifdef _DEBUG
+    std::cout << "save size = " << savesize << std::endl;
+#endif
+    }
     
     free( data );
 
-    return true;
+    return ret;
+}
+
+//
+// mv
+//
+bool CACHE::jdmv( const std::string& file_from, const std::string& file_to )
+{
+    if( CACHE::jdcopy( file_from, file_to ) ){
+        unlink( file_from.c_str() );
+        return true;
+    }
+
+    return false;
+}
+
+
+//
+// 保存ダイアログを表示して file_from を file_to に保存する
+//
+// parent == NULL の時はメインウィンドウをparentにする
+// file_toはデフォルトの保存先
+// 戻り値は保存先(保存に失敗したらempty())
+//
+std::string CACHE::copy_file( Gtk::Window* parent, const std::string& file_from, const std::string& file_to, const int type )
+{
+    if( file_from.empty() ) return std::string();
+    if( file_to.empty() ) return std::string();
+
+    std::string name = MISC::get_filename( file_to );
+    std::string dir = MISC::get_dir( file_to );
+    if( dir.empty() ) dir = MISC::get_dir( file_from );
+
+#ifdef _DEBUG
+    std::cout << "CACHE::open_copy_diag\n";
+    std::cout << "from = " << file_from  << std::endl;
+    std::cout << "dir = " << dir << std::endl;
+    std::cout << "name = " << name << std::endl;
+#endif
+
+    std::string path_to = CACHE::open_save_diag( parent, dir, name, type );
+    if( path_to.empty() ) return std::string();
+
+    if( CACHE::jdcopy( file_from, path_to ) ) return path_to;
+    else{
+        SKELETON::MsgDiag mdiag( parent, file_to + "\n\nの保存に失敗しました。\nハードディスクの容量やパーミッションなどを確認してください。" );
+        mdiag.run();
+    }
+
+    return std::string();
+}
+
+
+// ファイル選択ダイアログにフィルタ追加
+void CACHE::add_filter_to_diag( Gtk::FileChooserDialog& diag, const int type )
+{
+    if( type == FILE_TYPE_ALL ) return;
+
+    Gtk::FileFilter filter;
+    switch( type ) 
+    {
+        case FILE_TYPE_TEXT:
+            filter.set_name( "全てのテキストファイル" );
+            filter.add_mime_type( "text/plain" );
+            diag.add_filter( filter );
+            break;
+
+        case FILE_TYPE_DAT:
+            filter.set_name( "全てのDATファイル" );
+            filter.add_pattern( "*.dat" );
+            diag.add_filter( filter );
+            break;
+    }
+
+    Gtk::FileFilter all;
+    all.set_name( "全てのファイル" );
+    all.add_pattern( "*" );
+    diag.add_filter( all );
 }
 
 
@@ -595,21 +863,7 @@ std::string CACHE::open_load_diag( Gtk::Window* parent, const std::string& open_
     SKELETON::FileDiag diag( parent, "ファイルを開く", Gtk::FILE_CHOOSER_ACTION_OPEN );
 
     diag.set_current_folder( dir );
-
-    Gtk::FileFilter filter;
-    switch( type ) 
-    {
-        case FILE_TYPE_TEXT:
-            filter.set_name( "全てのテキストファイル" );
-            filter.add_mime_type( "text/plain" );
-            diag.add_filter( filter );
-            break;
-    }
-
-    Gtk::FileFilter all;
-    all.set_name( "全てのファイル" );
-    all.add_pattern( "*" );
-    diag.add_filter( all );
+    add_filter_to_diag( diag, type );
 
     if( diag.run() == Gtk::RESPONSE_ACCEPT )
     {
@@ -622,63 +876,58 @@ std::string CACHE::open_load_diag( Gtk::Window* parent, const std::string& open_
 }
 
 
-
 //
-// 保存ダイアログを表示して file_from を 保存する
+// 保存ファイル選択ダイアログを表示する
 //
 // parent == NULL の時はメインウィンドウをparentにする
-// file_toはデフォルトの保存先
-// 戻り値は保存先(保存に失敗したらempty())
+// dirとnameはデフォルトの参照先
+// 戻り値は選択されたファイルのpath
 //
-std::string CACHE::open_save_diag( Gtk::Window* parent, const std::string& file_from, const std::string& file_to )
+std::string CACHE::open_save_diag( Gtk::Window* parent, const std::string& dir, const std::string& name, const int type )
 {
-    if( file_from.empty() ) return std::string();
-    if( file_to.empty() ) return std::string();
-
-    SKELETON::FileDiag diag( parent, "save", Gtk::FILE_CHOOSER_ACTION_SAVE );
-
-    std::string name = MISC::get_filename( file_to );
-    std::string dir = MISC::get_dir( file_to );
-    if( dir.empty() ) dir = MISC::get_dir( file_from );
-
 #ifdef _DEBUG
-    std::cout << "CACHE::open_copy_diag\n";
-    std::cout << "from = " << file_from  << std::endl;
+    std::cout << "CACHE::open_save_diag\n";
     std::cout << "dir = " << dir << std::endl;
     std::cout << "name = " << name << std::endl;
 #endif
 
+    SKELETON::FileDiag diag( parent, "保存先選択", Gtk::FILE_CHOOSER_ACTION_SAVE );
     diag.set_current_folder( dir );
     diag.set_current_name( name );
-   
-    if( diag.run() == Gtk::RESPONSE_ACCEPT ){
+    add_filter_to_diag( diag, type );
 
-        diag.hide();
+    if( diag.run() != Gtk::RESPONSE_ACCEPT ) return std::string();
+    diag.hide();
         
-        std::string path_to = diag.get_filename();
+    std::string path_to = diag.get_filename();
 
 #ifdef _DEBUG
-        std::cout << "to   = " << path_to  << std::endl;
+    std::cout << "to   = " << path_to  << std::endl;
 #endif
 
-        // 既にファイルがある場合は問い合わせる
-        if( CACHE::file_exists( path_to ) == CACHE::EXIST_FILE ){
+    // 既にファイルがある場合は問い合わせる
+    if( CACHE::file_exists( path_to ) == CACHE::EXIST_FILE ){
 
-            SKELETON::MsgDiag mdiag( parent, "ファイルが存在します。ファイル名を変更しますか？",
-                                      false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_OK_CANCEL );
+        SKELETON::MsgDiag mdiag( parent, "ファイルが存在します。ファイル名を変更して保存しますか？", 
+                                 false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_NONE );
+        mdiag.add_button( Gtk::Stock::NO, Gtk::RESPONSE_NO );
+        mdiag.add_button( Gtk::Stock::YES, Gtk::RESPONSE_YES );
+        mdiag.add_button( "上書き", Gtk::RESPONSE_YES + 100 );
 
-            if( mdiag.run() ==  Gtk::RESPONSE_OK ) return CACHE::open_save_diag( parent, file_from,  path_to );
+        int ret = mdiag.run();
+        mdiag.hide();
 
-            return std::string();
+        if( ret ==  Gtk::RESPONSE_YES ){
+            return CACHE::open_save_diag( parent, MISC::get_dir( path_to ), MISC::get_filename( path_to ), type );
         }
-
-        if( CACHE::jdcopy( file_from, path_to ) ) return path_to;
+        else if( ret == Gtk::RESPONSE_NO ) return std::string();
     }
 
-    return std::string();
+    return path_to;
 }
 
 
+
 //
 // dir ディレクトリ内のレギュラーファイルのリストを取得
 //
