@@ -30,6 +30,7 @@
 #include "cache.h"
 #include "session.h"
 #include "colorid.h"
+#include "global.h"
 
 #include <sstream>
 #include <sys/time.h>
@@ -39,6 +40,8 @@ using namespace MESSAGE;
 
 #define MAX_STR_ICONV 128*1024
 
+#define PASS_TIMEOUT 500
+#define PASS_MAXTIME 120
 
 enum{
     PAGE_MESSAGE = 0,
@@ -51,13 +54,15 @@ MessageViewBase::MessageViewBase( const std::string& url )
       m_post( 0 ),
       m_preview( 0 ),
       m_enable_menuslot( true ),
+      m_enable_focus( true ),
       m_button_write( ICON::WRITE ),
       m_button_cancel( Gtk::Stock::CLOSE ),
       m_button_open( Gtk::Stock::OPEN ),
       m_button_undo( Gtk::Stock::UNDO ),
       m_button_not_close( Gtk::Stock::CANCEL ),
       m_button_preview( ICON::THREAD ),
-      m_entry_subject( false, " [ " + DBTREE::board_name( url ) + " ]  ", "" )
+      m_entry_subject( false, " [ " + DBTREE::board_name( url ) + " ]  ", "" ),
+      m_counter( 0 )
 {
 #ifdef _DEBUG
     std::cout << "MessageViewBase::MessageViewBase " << get_url() << std::endl;
@@ -114,6 +119,23 @@ const std::string MessageViewBase::url_for_copy()
 void MessageViewBase::clock_in()
 {
     if( m_preview ) m_preview->clock_in();
+
+    // 経過時刻表示
+    ++m_counter;
+    if( m_counter % ( PASS_TIMEOUT / TIMER_TIMEOUT ) == 0 ){
+
+        m_counter = 0;
+
+        time_t left = DBTREE::board_write_leftsec( get_url() );
+        if( left ){
+            m_str_pass = "  ( 書込規制中 残り " + MISC::itostr( left ) + " 秒 )";
+            MESSAGE::get_admin()->set_command( "set_status", get_url(), get_status() + m_str_pass );
+        }
+        else if( ! m_str_pass.empty() ){
+            m_str_pass = std::string();
+            MESSAGE::get_admin()->set_command( "set_status", get_url(), get_status() );
+        }
+    }
 }
 
 
@@ -171,6 +193,18 @@ bool MessageViewBase::set_command( const std::string& command, const std::string
     else if( command == "tab_right" ) tab_right();
     else if( command == "focus_write" ) focus_writebutton();
 
+    // メッセージをクリア
+    else if( command == "clear_message" ){
+
+        m_text_message.set_text( std::string() );
+
+        if( m_notebook.get_current_page() != PAGE_MESSAGE ){
+            m_enable_focus = false;
+            m_notebook.set_current_page( PAGE_MESSAGE );
+            m_enable_focus = true;
+        }
+    }
+
     // メッセージを追加
     else if( command == "add_message" )
     {
@@ -195,6 +229,27 @@ bool MessageViewBase::set_command( const std::string& command, const std::string
         m_text_message.insert_str( arg, true );
     }
 
+    // メッセージ保存
+    else if ( "save_message" )
+    {
+        if( ! get_message().empty() ){
+
+            std::string filename = "draft-" + MISC::get_filename( get_url() );
+            if( filename.find( ".dat" ) != std::string::npos ) filename = MISC::replace_str( filename, ".dat", ".txt" );
+            else filename += ".txt";
+            std::string save_to = CACHE::open_save_diag( MESSAGE::get_admin()->get_win(), SESSION::get_dir_draft(), filename, CACHE::FILE_TYPE_TEXT );
+            if( ! save_to.empty() ){
+
+                SESSION::set_dir_draft( MISC::get_dir( save_to ) );
+
+                if( CACHE::save_rawdata( save_to, get_message() ) != get_message().raw().length() ){
+                    SKELETON::MsgDiag mdiag( MESSAGE::get_admin()->get_win(),
+                                             "保存に失敗しました。\nハードディスクの容量やパーミッションなどを確認してください。" );
+                    mdiag.run();
+                }
+            }
+        }
+    }
 
     return false;
 }
@@ -235,7 +290,7 @@ void MessageViewBase::pack_widget()
     m_button_not_close.set_active( ! SESSION::get_close_mes() );
 
     m_button_write.signal_clicked().connect( sigc::mem_fun( *this, &MessageViewBase::slot_write_clicked ) );
-    m_button_cancel.signal_clicked().connect( sigc::mem_fun( *this, &MessageViewBase::close_view ) );
+    m_button_cancel.signal_clicked().connect( sigc::mem_fun( *this, &MessageViewBase::slot_close_clicked ) );
     m_button_open.signal_clicked().connect( sigc::mem_fun( *this, &MessageViewBase::slot_draft_open ) );
     m_button_undo.signal_clicked().connect( sigc::mem_fun( *this, &MessageViewBase::slot_undo_clicked ) );
     m_button_not_close.signal_clicked().connect( sigc::mem_fun( *this, &MessageViewBase::slot_not_close_clicked ) );
@@ -259,7 +314,8 @@ void MessageViewBase::pack_widget()
     m_toolbar.pack_start( m_button_not_close, Gtk::PACK_SHRINK );
     m_toolbar.pack_start( m_button_cancel, Gtk::PACK_SHRINK );
 
-
+    if( SESSION::get_close_mes() ) m_button_cancel.set_sensitive( true );
+    else m_button_cancel.set_sensitive( false );
 
     // 書き込みビュー
     m_label_name.set_alignment( Gtk::ALIGN_LEFT, Gtk::ALIGN_CENTER );
@@ -289,7 +345,12 @@ void MessageViewBase::pack_widget()
         m_entry_mail.set_text( DBTREE::write_mail( get_url() ) );
     }
     else if( ! DBTREE::board_get_write_mail( get_url() ).empty() ){
-        m_entry_mail.set_text( DBTREE::board_get_write_mail( get_url() ) );
+
+        std::string tmpmail = DBTREE::board_get_write_mail( get_url() );
+
+        // 空白セット
+        if( tmpmail == JD_MAIL_BLANK ) m_entry_mail.set_text( std::string() );
+        else m_entry_mail.set_text( tmpmail );
     }
     else m_entry_mail.set_text( "sage" );
 
@@ -363,7 +424,7 @@ void MessageViewBase::operate_view( const int& control )
             
             // 書き込まずに閉じる
         case CONTROL::CancelWrite:
-            MESSAGE::get_admin()->set_command( "close_currentview" );
+            close_view();
             break;
 
             // 書き込み実行
@@ -393,6 +454,13 @@ void MessageViewBase::operate_view( const int& control )
 //
 void MessageViewBase::slot_write_clicked()
 {
+    time_t left = DBTREE::board_write_leftsec( get_url() );
+    if( left ){
+        SKELETON::MsgDiag mdiag( MESSAGE::get_admin()->get_win(), "書き込み規制中です ( 残り " + MISC::itostr( left ) + " 秒 )\n\nもう暫くお待ち下さい。規制秒数が短くなった場合は板のプロパティからリセットできます。" );
+        mdiag.run();
+        return;
+    }
+
     if( m_post && m_post->is_loading() ){
         SKELETON::MsgDiag mdiag( MESSAGE::get_admin()->get_win(), "書き込み中です" );
         mdiag.run();
@@ -456,6 +524,19 @@ void MessageViewBase::slot_draft_open()
 }
 
 
+//
+// closeボタンを押した
+//
+void MessageViewBase::slot_close_clicked()
+{
+    if( !SESSION::get_close_mes() ){
+        SKELETON::MsgDiag mdiag( MESSAGE::get_admin()->get_win(), "「ビューを閉じない」ボタンが押されています。" );
+        mdiag.run();
+    }
+    else close_view();
+}
+
+
 //
 // undoボタンを押した
 //
@@ -473,6 +554,9 @@ void MessageViewBase::slot_not_close_clicked()
     if( ! m_enable_menuslot ) return;
 
     SESSION::set_close_mes( ! SESSION::get_close_mes() );
+
+    if( SESSION::get_close_mes() ) m_button_cancel.set_sensitive( true );
+    else m_button_cancel.set_sensitive( false );
 }
 
 
@@ -634,8 +718,7 @@ void MessageViewBase::post_fin()
         save_postlog();
         m_text_message.set_text( std::string() );
 
-        if( SESSION::get_close_mes() ) close_view();
-        else m_notebook.set_current_page( PAGE_MESSAGE );
+        close_view();
 
         reload();
     }
@@ -725,6 +808,7 @@ void MessageViewBase::slot_switch_page( GtkNotebookPage*, guint page )
         std::cout << ss.str() << std::endl;
 #endif
 
+        m_preview->set_command( "clear_screen" );
         m_preview->set_command( "append_dat", ss.str() );
     }
 
@@ -737,8 +821,10 @@ void MessageViewBase::slot_switch_page( GtkNotebookPage*, guint page )
         m_button_preview.set_active( false );
     }
 
-    MESSAGE::get_admin()->set_command( "switch_admin" );
-    MESSAGE::get_admin()->set_command( "focus_current_view" );
+    if( m_enable_focus ){
+        MESSAGE::get_admin()->set_command( "switch_admin" );
+        MESSAGE::get_admin()->set_command( "focus_current_view" );
+    }
 
     m_enable_menuslot = true;
 }
@@ -766,10 +852,12 @@ void MessageViewBase::show_status()
     ss << "   /  文字数 " << m_lng_str_enc;
     if( m_max_str ) ss << "/ " << m_max_str;
 
+    if( DBTREE::article_write_time( get_url() ) ) ss << "  /  最終書込 " << DBTREE::article_write_date( get_url() );
+
     ss << " ]";
 
     set_status( ss.str() );
-    MESSAGE::get_admin()->set_command( "set_status", get_url(), get_status() );
+    MESSAGE::get_admin()->set_command( "set_status", get_url(), get_status() + m_str_pass );
 }
 
 
