@@ -5,6 +5,7 @@
 
 #include "session.h"
 #include "cache.h"
+#include "global.h"
 
 #include "jdlib/confloader.h"
 #include "jdlib/miscutil.h"
@@ -19,11 +20,6 @@ bool mode_online;
 bool mode_login2ch;
 
 int win_manager;
-int win_x;
-int win_y;
-int win_width;
-int win_height;
-bool win_maximized;
 
 int win_hpane_main_pos;
 int win_vpane_main_pos;
@@ -36,9 +32,17 @@ int win_bbslist_page;
 int win_board_page;
 int win_article_page;
 int win_image_page;
+
 std::list< std::string > board_urls;
+std::list< bool > board_locked;
+
 std::list< std::string > article_urls;
+std::list< bool > article_locked;
+
 std::list< std::string > image_urls;
+std::list< bool > image_locked;
+
+std::string items_board;
 
 int board_col_mark;
 int board_col_id;
@@ -50,41 +54,61 @@ int board_col_since;
 int board_col_write;
 int board_col_speed;
 
-bool img_shown;
-
 bool win_show_sidebar;
 
 bool win_show_menubar;
 
 int win_toolbar_pos;
 
+bool show_bbslist_toolbar;
+bool show_board_toolbar;
+bool show_article_toolbar;
+
+bool show_board_tab;
+bool show_article_tab;
+
 int win_focused_admin;
 int win_focused_admin_sidebar;
 
-bool focus_win_main;
-bool focus_win_img;
+int x_win_main;
+int y_win_main;
+int x_win_img;
+int y_win_img;
+int x_win_mes;
+int y_win_mes;
+
+
+int width_win_main;
+int height_win_main;
+int width_win_img;
+int height_win_img;
+int width_win_mes;
+int height_win_mes;
+
+
+bool focus_win_main = false;
+bool focus_win_img = false;
+bool focus_win_mes = false;
+
+bool maximized_win_main = false;
+bool maximized_win_img = false;
+bool maximized_win_mes = false;
 
 bool iconified_win_main = false;
 bool iconified_win_img = false;
+bool iconified_win_mes = false;
+
+bool shown_win_main = false;
+bool shown_win_img = false;
+bool shown_win_mes = false;
 
 bool dialog_shown = false;
 
 bool embedded_img;
 
-int img_x;
-int img_y;
-int img_width;
-int img_height;
-
 bool embedded_mes;
 bool close_mes;
 
-int win_mes_x;
-int win_mes_y;
-int win_mes_width;
-int win_mes_height;
-bool win_mes_maximized;
-
 std::string img_dir_dat_save;
 std::string img_dir_img_save;
 
@@ -96,15 +120,38 @@ bool popupmenu_shown;
 /////////////////////////////////////
 
 
+void read_list_urls( JDLIB::ConfLoader& cf, const std::string& id_urls, const std::string& id_locked,
+                     std::list< std::string >& list_urls , std::list< bool >& list_locked )
+{
+    std::string str_tmp;
+    std::list< std::string > list_tmp;
+    std::list< std::string >::iterator it_tmp;
+
+    str_tmp = cf.get_option( id_urls, "");
+    if( ! str_tmp.empty() ){
+        list_tmp = MISC::split_line( str_tmp );
+        it_tmp = list_tmp.begin();
+        for( ; it_tmp != list_tmp.end(); ++it_tmp ) if( !(*it_tmp).empty() ) list_urls.push_back( (*it_tmp));
+    }
+
+    str_tmp = cf.get_option( id_locked, "");
+    if( ! str_tmp.empty() ){
+        list_tmp = MISC::split_line( str_tmp );
+        it_tmp = list_tmp.begin();
+        for( ; it_tmp != list_tmp.end(); ++it_tmp ){
+            if( ( *it_tmp ) == "1" ) list_locked.push_back( true );
+            else list_locked.push_back( false );
+        }
+    }
+}
+
+
 // セッション情報読み込み
 void SESSION::init_session()
 {
 #ifdef _DEBUG
     std::cout << "SESSION::init_session\n";
 #endif
-    std::string str_tmp;
-    std::list< std::string > list_tmp;
-    std::list< std::string >::iterator it_tmp;
 
     JDLIB::ConfLoader cf( CACHE::path_session(), std::string() );
 
@@ -117,11 +164,11 @@ void SESSION::init_session()
     // paneのモード
     mode_pane = cf.get_option( "mode_pane", 0 );
 
-    win_x = cf.get_option( "x", 0 );
-    win_y = cf.get_option( "y", 0 );
-    win_width = cf.get_option( "width", 800 );
-    win_height = cf.get_option( "height", 600 );
-    win_maximized = cf.get_option( "maximized", false );
+    x_win_main = cf.get_option( "x", 0 );
+    y_win_main = cf.get_option( "y", 0 );
+    width_win_main = cf.get_option( "width", 800 );
+    height_win_main = cf.get_option( "height", 600 );
+    maximized_win_main = cf.get_option( "maximized", false );
 
     win_show_sidebar = cf.get_option( "show_sidebar", true );
 
@@ -129,6 +176,13 @@ void SESSION::init_session()
 
     win_toolbar_pos = cf.get_option( "toolbar_pos", 0 );
 
+    show_bbslist_toolbar = cf.get_option( "show_bbslist_toolbar", true );
+    show_board_toolbar = cf.get_option( "show_board_toolbar", true );
+    show_article_toolbar = cf.get_option( "show_article_toolbar", true );
+
+    show_board_tab = cf.get_option( "show_board_tab", true );
+    show_article_tab = cf.get_option( "show_article_tab", true );
+
     win_focused_admin = cf.get_option( "focused_admin", FOCUS_NO );
     win_focused_admin_sidebar = cf.get_option( "focused_admin_sidebar", FOCUS_NO );
 
@@ -144,26 +198,20 @@ void SESSION::init_session()
     win_article_page = cf.get_option( "article_page", 0 );
     win_image_page = cf.get_option( "image_page", 0 );
 
-    str_tmp = cf.get_option( "board_urls", "");
-    if( ! str_tmp.empty() ){
-        list_tmp = MISC::split_line( str_tmp );
-        it_tmp = list_tmp.begin();
-        for( ; it_tmp != list_tmp.end(); ++it_tmp ) if( !(*it_tmp).empty() ) board_urls.push_back( (*it_tmp));
-    }
+    read_list_urls( cf, "board_urls", "board_locked", board_urls, board_locked );
+    read_list_urls( cf, "article_urls", "article_locked", article_urls, article_locked );
+    read_list_urls( cf, "image_urls", "image_locked", image_urls, image_locked );
 
-    str_tmp = cf.get_option( "article_urls", "");
-    if( ! str_tmp.empty() ){
-        list_tmp = MISC::split_line( str_tmp );
-        it_tmp = list_tmp.begin();
-        for( ; it_tmp != list_tmp.end(); ++it_tmp ) if( !(*it_tmp).empty() ) article_urls.push_back( (*it_tmp));
-    }
-
-    str_tmp = cf.get_option( "image_urls", "");
-    if( ! str_tmp.empty() ){
-        list_tmp = MISC::split_line( str_tmp );
-        it_tmp = list_tmp.begin();
-        for( ; it_tmp != list_tmp.end(); ++it_tmp ) if( !(*it_tmp).empty() ) image_urls.push_back( (*it_tmp));
-    }
+    items_board = cf.get_option( "items_board",
+                                 COLUMN_TITLE_MARK + std::string ( " " ) +
+                                 COLUMN_TITLE_ID + std::string ( " " ) +
+                                 COLUMN_TITLE_NAME + std::string ( " " ) +
+                                 COLUMN_TITLE_RES + std::string ( " " ) +
+                                 COLUMN_TITLE_LOAD + std::string ( " " ) +
+                                 COLUMN_TITLE_NEW + std::string ( " " ) +
+                                 COLUMN_TITLE_SINCE + std::string ( " " ) +
+                                 COLUMN_TITLE_WRITE + std::string ( " " ) +
+                                 COLUMN_TITLE_SPEED + std::string ( " " ) );
 
     board_col_mark = cf.get_option( "col_mark", 30 );
     board_col_id = cf.get_option( "col_id", 45 );
@@ -175,23 +223,20 @@ void SESSION::init_session()
     board_col_write = cf.get_option( "col_write", 70 );
     board_col_speed = cf.get_option( "col_speed", 45 );
 
-    img_shown = false;
-
     embedded_img = cf.get_option( "embedded_img", true );
 
-    img_x = cf.get_option( "img_x", 0 );
-    img_y = cf.get_option( "img_y", 0 );
-    img_width = cf.get_option( "img_width", 600 );
-    img_height = cf.get_option( "img_height", 500 );
+    x_win_img = cf.get_option( "x_win_img", 0 );
+    y_win_img = cf.get_option( "y_win_img", 0 );
+    width_win_img = cf.get_option( "width_win_img", 600 );
+    height_win_img = cf.get_option( "height_win_img", 400 );
 
     embedded_mes = cf.get_option( "embedded_mes", false );
     close_mes = cf.get_option( "close_mes", true );
 
-    win_mes_x = cf.get_option( "mes_x", 0 );
-    win_mes_y = cf.get_option( "mes_y", 0 );
-    win_mes_width = cf.get_option( "mes_width", 300 );
-    win_mes_height = cf.get_option( "mes_height", 300 );
-    win_mes_maximized = cf.get_option( "mes_maximized", false );
+    x_win_mes = cf.get_option( "x_win_mes", 0 );
+    y_win_mes = cf.get_option( "y_win_mes", 0 );
+    width_win_mes = cf.get_option( "width_win_mes", 600 );
+    height_win_mes = cf.get_option( "height_win_mes", 400 );
 
     img_dir_dat_save = cf.get_option( "img_dir_dat_save", "" );
     img_dir_img_save = cf.get_option( "img_dir_img_save", "" );
@@ -220,11 +265,11 @@ void SESSION::init_session()
     }
 
 #ifdef _DEBUG
-    std::cout << "x=" << win_x << std::endl
-              << "y=" << win_y << std::endl
-              << "w=" << win_width << std::endl
-              << "h=" << win_height << std::endl
-              << "m=" << win_maximized << std::endl
+    std::cout << "x=" << x_win_main << std::endl
+              << "y=" << y_win_main << std::endl
+              << "w=" << width_win_main << std::endl
+              << "h=" << height_win_main << std::endl
+              << "max=" << maximized_win_main << std::endl
               << "toolbar_pos=" << win_toolbar_pos << std::endl
               << "sidebar=" << win_show_sidebar << std::endl
               << "menubar=" << win_show_menubar << std::endl
@@ -267,12 +312,11 @@ void SESSION::init_session()
               << board_col_speed << std::endl
 
               << "embedded_mes = " << embedded_mes << std::endl
-              << "close_mes = " << close_mes << std::endl;
-              << "wx=" << win_mes_x << std::endl
-              << "wy=" << win_mes_y << std::endl
-              << "ww=" << win_mes_width << std::endl
-              << "wh=" << win_mes_height << std::endl
-              << "wm=" << win_mes_maximized << std::endl;
+              << "close_mes = " << close_mes << std::endl
+              << "wx=" << x_win_mes << std::endl
+              << "wy=" << y_win_mes << std::endl
+              << "ww=" << width_win_mes << std::endl
+              << "wh=" << height_win_mes << std::endl;
 #endif    
 }
 
@@ -281,33 +325,65 @@ void SESSION::init_session()
 // セッション情報保存
 void SESSION::save_session()
 {
+    // 開いているタブのURL
     std::string str_board_urls;
     std::string str_article_urls;
     std::string str_image_urls;
 
-    std::list< std::string >::iterator it = board_urls.begin();
-    for( ; it != board_urls.end(); ++it ){
-        if( ! ( *it ).empty() ) str_board_urls += " \"" + ( *it ) + "\"";
+    std::list< std::string >::iterator it_url = board_urls.begin();
+    for( ; it_url != board_urls.end(); ++it_url ){
+        if( ! ( *it_url ).empty() ) str_board_urls += " \"" + ( *it_url ) + "\"";
     }
-    it = article_urls.begin();
-    for( ; it != article_urls.end(); ++it ){
-        if( ! ( *it ).empty() ) str_article_urls += " \"" + ( *it ) + "\"";
+    it_url = article_urls.begin();
+    for( ; it_url != article_urls.end(); ++it_url ){
+        if( ! ( *it_url ).empty() ) str_article_urls += " \"" + ( *it_url ) + "\"";
     }
-    it = image_urls.begin();
-    for( ; it != image_urls.end(); ++it ){
-        if( ! ( *it ).empty() ) str_image_urls += " \"" + ( *it ) + "\"";
+    it_url = image_urls.begin();
+    for( ; it_url != image_urls.end(); ++it_url ){
+        if( ! ( *it_url ).empty() ) str_image_urls += " \"" + ( *it_url ) + "\"";
     }
 
+    // 開いているタブのロック状態
+    std::string str_board_locked;
+    std::string str_article_locked;
+    std::string str_image_locked;
+
+    std::list< bool >::iterator it_locked = board_locked.begin();
+    for( ; it_locked != board_locked.end(); ++it_locked ){
+        if( *it_locked ) str_board_locked += " 1";
+        else str_board_locked += " 0";
+    }
+
+    it_locked = article_locked.begin();
+    for( ; it_locked != article_locked.end(); ++it_locked ){
+        if( *it_locked ) str_article_locked += " 1";
+        else str_article_locked += " 0";
+    }
+
+    it_locked = image_locked.begin();
+    for( ; it_locked != image_locked.end(); ++it_locked ){
+        if( *it_locked ) str_image_locked += " 1";
+        else str_image_locked += " 0";
+    }
+
+
+    // 保存内容作成
+
     std::ostringstream oss;
     oss << "mode_pane = " << mode_pane << std::endl
         << "mode_online = " << mode_online << std::endl
         << "mode_login2ch = " << mode_login2ch << std::endl
-        << "x = " << win_x << std::endl
-        << "y = " << win_y << std::endl
-        << "width = " << win_width << std::endl
-        << "height = " << win_height << std::endl
-        << "maximized = " << win_maximized << std::endl
+        << "x = " << x_win_main << std::endl
+        << "y = " << y_win_main << std::endl
+        << "width = " << width_win_main << std::endl
+        << "height = " << height_win_main << std::endl
+        << "maximized = " << maximized_win_main << std::endl
         << "toolbar_pos = " << win_toolbar_pos << std::endl
+        << "show_bbslist_toolbar = " << show_bbslist_toolbar << std::endl
+        << "show_board_toolbar = " << show_board_toolbar << std::endl
+        << "show_article_toolbar = " << show_article_toolbar << std::endl
+        << "show_board_tab = " << show_board_tab << std::endl
+        << "show_article_tab = " << show_article_tab << std::endl
         << "show_sidebar = " << win_show_sidebar << std::endl
         << "show_menubar = " << win_show_menubar << std::endl
         << "focused_admin = " << win_focused_admin << std::endl
@@ -321,14 +397,20 @@ void SESSION::save_session()
         << "notebook_main_page = " << win_notebook_main_page << std::endl
 
         << "bbslist_page = " << win_bbslist_page << std::endl
-        << "board_page = " << win_board_page << std::endl
-        << "article_page = " << win_article_page << std::endl
-        << "image_page = " << win_image_page << std::endl
 
+        << "board_page = " << win_board_page << std::endl
         << "board_urls = " << str_board_urls << std::endl
+        << "board_locked = " << str_board_locked << std::endl
+
+        << "article_page = " << win_article_page << std::endl
         << "article_urls = " << str_article_urls << std::endl
+        << "article_locked = " << str_article_locked << std::endl
+
+        << "image_page = " << win_image_page << std::endl
         << "image_urls = " << str_image_urls << std::endl
-        
+        << "image_locked = " << str_image_locked << std::endl
+
+        << "items_board = " << items_board << std::endl
         << "col_mark = " << board_col_mark << std::endl
         << "col_id = " << board_col_id << std::endl
         << "col_subject = " << board_col_subject << std::endl
@@ -340,18 +422,17 @@ void SESSION::save_session()
         << "col_speed = " << board_col_speed << std::endl
 
         << "embedded_img = " << embedded_img << std::endl
-        << "img_x = " << img_x << std::endl
-        << "img_y = " << img_y << std::endl
-        << "img_width = " << img_width << std::endl
-        << "img_height = " << img_height << std::endl
+        << "x_win_img = " << x_win_img << std::endl
+        << "y_win_img = " << y_win_img << std::endl
+        << "width_win_img = " << width_win_img << std::endl
+        << "height_win_img = " << height_win_img << std::endl
 
         << "embedded_mes = " << embedded_mes << std::endl
         << "close_mes = " << close_mes << std::endl
-        << "mes_x = " << win_mes_x << std::endl
-        << "mes_y = " << win_mes_y << std::endl
-        << "mes_width = " << win_mes_width << std::endl
-        << "mes_height = " << win_mes_height << std::endl
-        << "mes_maximized = " << win_mes_maximized << std::endl
+        << "x_win_mes = " << x_win_mes << std::endl
+        << "y_win_mes = " << y_win_mes << std::endl
+        << "width_win_mes = " << width_win_mes << std::endl
+        << "height_win_mes = " << height_win_mes << std::endl
 
         << "img_dir_dat_save = " << img_dir_dat_save << std::endl
         << "img_dir_img_save = " << img_dir_img_save << std::endl
@@ -378,25 +459,69 @@ void SESSION::set_online( bool mode ){ mode_online = mode; }
 const bool SESSION::login2ch(){ return mode_login2ch; }
 void SESSION::set_login2ch( bool login ){ mode_login2ch = login; }
 
-int SESSION::x(){ return win_x; }
-int SESSION::y(){ return win_y; }
-int SESSION::width(){ return win_width; }
-int SESSION::height(){ return win_height; }
-bool SESSION::maximized(){ return win_maximized; }
-bool SESSION::show_sidebar(){ return win_show_sidebar; }
+const bool SESSION::show_sidebar(){ return win_show_sidebar; }
 
-bool SESSION::show_menubar(){ return win_show_menubar; }
+const bool SESSION::show_menubar(){ return win_show_menubar; }
 void SESSION::set_show_menubar( bool show ){ win_show_menubar = show; }
 
-int SESSION::toolbar_pos(){ return win_toolbar_pos; }
+const int SESSION::toolbar_pos(){ return win_toolbar_pos; }
 void SESSION::set_toolbar_pos( int pos ){ win_toolbar_pos = pos; }
 
-int SESSION::focused_admin(){ return win_focused_admin; }
+const bool SESSION::get_show_bbslist_toolbar(){ return show_bbslist_toolbar; }
+void SESSION::set_show_bbslist_toolbar( bool show ){ show_bbslist_toolbar = show; }
+
+const bool SESSION::get_show_board_toolbar(){ return show_board_toolbar; }
+void SESSION::set_show_board_toolbar( bool show ){ show_board_toolbar = show; }
+
+const bool SESSION::get_show_article_toolbar(){ return show_article_toolbar; }
+void SESSION::set_show_article_toolbar( bool show ){ show_article_toolbar = show; }
+
+const bool SESSION::get_show_board_tab(){ return show_board_tab; }
+void SESSION::set_show_board_tab( bool show ){ show_board_tab = show; }
+
+const bool SESSION::get_show_article_tab(){ return show_article_tab; }
+void SESSION::set_show_article_tab( bool show ){ show_article_tab = show; }
+
+const int SESSION::focused_admin(){ return win_focused_admin; }
 void SESSION::set_focused_admin( int admin ){ win_focused_admin = admin; }
 int SESSION::focused_admin_sidebar(){ return win_focused_admin_sidebar; }
 void SESSION::set_focused_admin_sidebar( int admin ){ win_focused_admin_sidebar = admin; }
 
 
+// 各windowの座標
+const int SESSION::get_x_win_main(){ return x_win_main; }
+const int SESSION::get_y_win_main(){ return y_win_main; }
+void SESSION::set_x_win_main( int x ){ x_win_main = x; }
+void SESSION::set_y_win_main( int y ){ y_win_main = y; }
+
+const int SESSION::get_x_win_img(){ return x_win_img; }
+const int SESSION::get_y_win_img(){ return y_win_img; }
+void SESSION::set_x_win_img( int x ){ x_win_img = x; }
+void SESSION::set_y_win_img( int y ){ y_win_img = y; }
+
+const int SESSION::get_x_win_mes(){ return x_win_mes; }
+const int SESSION::get_y_win_mes(){ return y_win_mes; }
+void SESSION::set_x_win_mes( int x ){ x_win_mes = x; }
+void SESSION::set_y_win_mes( int y ){ y_win_mes = y; }
+
+
+// 各windowのサイズ
+const int SESSION::get_width_win_main(){ return width_win_main; }
+const int SESSION::get_height_win_main(){ return height_win_main; }
+void SESSION::set_width_win_main( int width ){ width_win_main = width; }
+void SESSION::set_height_win_main( int height ){ height_win_main = height; }
+
+const int SESSION::get_width_win_img(){ return width_win_img; }
+const int SESSION::get_height_win_img(){ return height_win_img; }
+void SESSION::set_width_win_img( int width ){ width_win_img = width; }
+void SESSION::set_height_win_img( int height ){ height_win_img = height; }
+
+const int SESSION::get_width_win_mes(){ return width_win_mes; }
+const int SESSION::get_height_win_mes(){ return height_win_mes; }
+void SESSION::set_width_win_mes( int width ){ width_win_mes = width; }
+void SESSION::set_height_win_mes( int height ){ height_win_mes = height; }
+
+
 // 各window がフォーカスされているか
 const bool SESSION::is_focus_win_main(){ return focus_win_main; }
 void SESSION::set_focus_win_main( bool set ){ focus_win_main = set; }
@@ -404,28 +529,50 @@ void SESSION::set_focus_win_main( bool set ){ focus_win_main = set; }
 const bool SESSION::is_focus_win_img(){ return focus_win_img; }
 void SESSION::set_focus_win_img( bool set ){ focus_win_img = set; }
 
+const bool SESSION::is_focus_win_mes(){ return focus_win_mes; }
+void SESSION::set_focus_win_mes( bool set ){ focus_win_mes = set; }
 
-    // 各window が最小化されているか
+
+// 各window が最大化されているか
+const bool SESSION::is_maximized_win_main(){ return maximized_win_main; }
+void SESSION::set_maximized_win_main( bool set ){ maximized_win_main = set; }
+
+const bool SESSION::is_maximized_win_img(){ return maximized_win_img; }
+void SESSION::set_maximized_win_img( bool set ){ maximized_win_img = set; }
+
+bool SESSION::is_maximized_win_mes(){ return maximized_win_mes; }
+void SESSION::set_maximized_win_mes( bool set ){ maximized_win_mes = set; }
+
+
+// 各window が最小化されているか
 const bool SESSION::is_iconified_win_main(){ return iconified_win_main; }
 void SESSION::set_iconified_win_main( bool set ){ iconified_win_main = set; }
 
 const bool SESSION::is_iconified_win_img(){ return iconified_win_img; }
 void SESSION::set_iconified_win_img( bool set ){ iconified_win_img = set; }
 
+const bool SESSION::is_iconified_win_mes(){ return iconified_win_mes; }
+void SESSION::set_iconified_win_mes( bool set ){ iconified_win_mes = set; }
+
+
+// 各window が画面に表示されているか
+const bool SESSION::is_shown_win_main(){ return shown_win_main; }
+void SESSION::set_shown_win_main( bool set ){ shown_win_main = set; }
+
+const bool SESSION::is_shown_win_img(){ return shown_win_img; }
+void SESSION::set_shown_win_img( bool set ){ shown_win_img = set; }
+
+const bool SESSION::is_shown_win_mes(){ return shown_win_mes; }
+void SESSION::set_shown_win_mes( bool set ){ shown_win_mes = set; }
+
+
 // ダイアログ表示中
 const bool SESSION::is_dialog_shown(){ return dialog_shown; }
 void SESSION::set_dialog_shown( bool set ){ dialog_shown = set; }
 
-
-void SESSION::set_x( int x ){ win_x = x; }
-void SESSION::set_y( int y ){ win_y = y; }
-void SESSION::set_width( int width ){ win_width = width; }
-void SESSION::set_height( int height ){ win_height = height; }
-void SESSION::set_maximized( bool maximized ){ win_maximized = maximized; }
 void SESSION::set_show_sidebar( bool showurl ){ win_show_sidebar = showurl; }
 
 
-
 // メインウィンドウのペインの敷居の位置
 int SESSION::hpane_main_pos(){ return win_hpane_main_pos; }
 int SESSION::vpane_main_pos(){ return win_vpane_main_pos; }
@@ -452,13 +599,19 @@ void SESSION::set_board_page( int page ){ win_board_page = page; }
 const std::list< std::string >& SESSION::board_URLs(){ return board_urls; }
 void SESSION::set_board_URLs( const std::list< std::string >& urls ){ board_urls = urls; }
 
+// スレ一覧のロック状態
+const std::list< bool >& SESSION::get_board_locked(){ return board_locked; }
+void SESSION::set_board_locked( const std::list< bool >& locked ){ board_locked = locked; }
 
-// 前回閉じたときに開いていたarticleのページ番号とURL
+// 前回閉じたときに開いていたスレタブのページ番号とURL
 int SESSION::article_page(){ return win_article_page; }
 void SESSION::set_article_page( int page ){ win_article_page = page; }
-const std::list< std::string >& SESSION::article_URLs(){ return article_urls; }
+const std::list< std::string >& SESSION::get_article_URLs(){ return article_urls; }
 void SESSION::set_article_URLs( const std::list< std::string >& urls ){ article_urls = urls; }
 
+// スレタブのロック状態
+const std::list< bool >& SESSION::get_article_locked(){ return article_locked; }
+void SESSION::set_article_locked( const std::list< bool >& locked ){ article_locked = locked; }
 
 // 前回閉じたときに開いていたimageのページ番号とURL
 int SESSION::image_page(){ return win_image_page; }
@@ -466,6 +619,13 @@ void SESSION::set_image_page( int page ){ win_image_page = page; }
 const std::list< std::string >& SESSION::image_URLs(){ return image_urls; }
 void SESSION::set_image_URLs( const std::list< std::string >& urls ){ image_urls = urls; }
 
+// 画像タブのロック状態
+const std::list< bool >& SESSION::get_image_locked(){ return image_locked; }
+void SESSION::set_image_locked( const std::list< bool >& locked ){ image_locked = locked; }
+
+// スレ一覧の項目
+const std::string& SESSION::get_items_board(){ return items_board; }
+void SESSION::set_items_board( const std::string& items ){ items_board = items; }
 
 // board ビューの列幅
 int SESSION::col_mark(){ return board_col_mark; }
@@ -510,24 +670,10 @@ const std::string SESSION::get_article_current_url()
 }
 
 
-bool SESSION::is_img_shown(){ return img_shown; }
-void SESSION::set_img_shown( bool set ){ img_shown = set; }
-
-
 // 埋め込みimage使用
 bool SESSION::get_embedded_img(){ return embedded_img; }
 void SESSION::set_embedded_img( bool set ){ embedded_img = set; }
 
-int SESSION::get_img_x(){ return img_x; }
-int SESSION::get_img_y(){ return img_y; }
-int SESSION::get_img_width(){ return img_width; }
-int SESSION::get_img_height(){ return img_height; }
-
-void SESSION::set_img_x( int x ){ img_x = x; }
-void SESSION::set_img_y( int y ){ img_y = y; }
-void SESSION::set_img_width( int width ){ img_width = width; }
-void SESSION::set_img_height( int height ){ img_height = height; }
-
 
 // 埋め込みmessageを使用
 bool SESSION::get_embedded_mes(){ return embedded_mes; }
@@ -538,20 +684,6 @@ bool SESSION::get_close_mes(){ return close_mes; }
 void SESSION::set_close_mes( bool set ){ close_mes = set; }
 
 
-// message ウィンドウの位置
-int SESSION::mes_x(){ return win_mes_x; }
-int SESSION::mes_y(){ return win_mes_y; }
-int SESSION::mes_width(){ return win_mes_width; }
-int SESSION::mes_height(){ return win_mes_height; }
-bool SESSION::mes_maximized(){ return win_mes_maximized; }
-
-void SESSION::set_mes_x( int x ){ win_mes_x = x; }
-void SESSION::set_mes_y( int y ){ win_mes_y = y; }
-void SESSION::set_mes_width( int width ){ win_mes_width = width; }
-void SESSION::set_mes_height( int height ){ win_mes_height = height; }
-void SESSION::set_mes_maximized( bool maximized ){ win_mes_maximized = maximized; }
-
-
 // 最後にdatを保存したディレクトリ
 const std::string& SESSION::dir_dat_save(){ return img_dir_dat_save; }
 void SESSION::set_dir_dat_save( const std::string& dir ){ img_dir_dat_save = dir; }
